==> progamification-1.3.0.tar.gz: lib/src/widgets/rank.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/constants/color_contants.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:progamification/src/widgets/avatar_placeholder.dart';
import 'package:progamification/src/widgets/bolt.dart';

class Rank extends StatefulWidget {
  const Rank({super.key});

  @override
  State<Rank> createState() => _RankState();
}

class _RankState extends State<Rank> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  LeaderBoardModel currentUser = LeaderBoardModel();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  String userId = '';
  @override
  initState() {
    super.initState();

    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  TextStyle textStyle(fontSize) => TextStyle(
        fontWeight: FontWeight.w600,
        fontSize: fontSize,
        fontFamily: GoogleFonts.plusJakartaSans().fontFamily,
      );
  @override
  Widget build(BuildContext context) {
    return Container(
        decoration: const BoxDecoration(
          color: Colors.white,
        ),
        padding: const EdgeInsets.only(
            top: 25.0, left: 5.0, right: 5.0, bottom: 30.0),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Stack(
                clipBehavior: Clip.none,
                children: [
                  Container(
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                        child: CachedNetworkImage(
                      key: UniqueKey(),
                      imageUrl: leaderBoardController
                              .leaderBoardData[1].profileImageUrl
                              .toString() +
                          sasToken,
                      width: 55.0,
                      height: 55.0,
                      fit: BoxFit.fill,
                      placeholder: (context, url) => const AvatarPlaceHolder(),
                      errorWidget: (context, url, error) =>
                          const AvatarPlaceHolder(),
                    )),
                  ),
                  Positioned(
                    bottom: -14,
                    left: 15,
                    child: Container(
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: ColorConstants.rankColor,
                          border: Border.all(
                            color: Colors.white,
                            width: 1.5,
                          ),
                        ),
                        child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Text(
                              leaderBoardController.leaderBoardData[1].rank
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: textStyle(14.0),
                            ))),
                  ),
                ],
              ),
              Padding(
                  padding: const EdgeInsets.only(top: 10.0),
                  child: Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        SizedBox(
                            width: 100,
                            child: Text(
                              leaderBoardController.leaderBoardData[1].userName
                                  .toString(),
                              style: textStyle(16.0),
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                              textAlign: TextAlign.center,
                            )),
                        Row(
                          children: [
                            const Bolt(
                              height: 25,
                              width: 25,
                            ),
                            Text(
                              '${leaderBoardController.leaderBoardData[1].score}',
                              style: textStyle(16.0),
                            )
                          ],
                        )
                      ]))
            ]),
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Stack(clipBehavior: Clip.none, children: [
                  Container(
                      decoration: const BoxDecoration(
                        shape: BoxShape.circle,
                      ),
                      child: ClipOval(
                        child: CachedNetworkImage(
                            key: UniqueKey(),
                            imageUrl: leaderBoardController
                                    .leaderBoardData[0].profileImageUrl
                                    .toString() +
                                sasToken,
                            width: 75,
                            height: 75,
                            fit: BoxFit.fill,
                            placeholder: (context, url) =>
                                const AvatarPlaceHolder(),
                            errorWidget: (context, url, error) =>
                                const AvatarPlaceHolder()),
                      )),
                  Positioned(
                    bottom: -14,
                    left: 26,
                    child: Container(
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: ColorConstants.rankColor,
                          border: Border.all(
                            color: Colors.white,
                            width: 1.5,
                          ),
                        ),
                        child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Text(
                              leaderBoardController.leaderBoardData[0].rank
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: textStyle(14.0),
                            ))),
                  ),
                ]),
                Padding(
                    padding: const EdgeInsets.only(top: 10.0),
                    child: Column(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          SizedBox(
                              width: 100,
                              child: Text(
                                leaderBoardController
                                    .leaderBoardData[0].userName
                                    .toString(),
                                style: textStyle(16.0),
                                softWrap: false,
                                overflow: TextOverflow.ellipsis,
                                textAlign: TextAlign.center,
                              )),
                          Row(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: [
                              const Bolt(
                                height: 25,
                                width: 25,
                              ),
                              Text(
                                '${leaderBoardController.leaderBoardData[0].score}',
                                style: textStyle(16.0),
                              )
                            ],
                          )
                        ]))
              ],
            ),
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Stack(clipBehavior: Clip.none, children: [
                Container(
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                      child: CachedNetworkImage(
                        key: UniqueKey(),
                        imageUrl: leaderBoardController
                                .leaderBoardData[2].profileImageUrl
                                .toString() +
                            sasToken,
                        width: 55.0,
                        height: 55.0,
                        fit: BoxFit.fill,
                        placeholder: (context, url) =>
                            const AvatarPlaceHolder(),
                        errorWidget: (context, url, error) =>
                            const AvatarPlaceHolder(),
                      ),
                    )),
                Positioned(
                  bottom: -13,
                  left: 15,
                  child: Container(
                      decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: ColorConstants.rankColor,
                        border: Border.all(
                          color: Colors.white,
                          width: 1.5,
                        ),
                      ),
                      child: Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Text(
                            leaderBoardController.leaderBoardData[2].rank
                                .toString(),
                            textAlign: TextAlign.start,
                            style: textStyle(14.0),
                          ))),
                ),
              ]),
              Padding(
                padding: const EdgeInsets.only(top: 10.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    SizedBox(
                        width: 100,
                        child: Text(
                          leaderBoardController.leaderBoardData[2].userName
                              .toString(),
                          style: textStyle(16.0),
                          softWrap: false,
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.center,
                        )),
                    Row(
                      children: [
                        const Bolt(
                          height: 25,
                          width: 25,
                        ),
                        Text(
                          '${leaderBoardController.leaderBoardData[2].score}',
                          style: textStyle(16.0),
                        )
                      ],
                    )
                  ],
                ),
              )
            ]),
          ],
        ));
  }
}

==> progamification-1.7.0.tar.gz: lib/src/widgets/rank.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:progamification/src/widgets/avatar_placeholder.dart';

class Rank extends StatefulWidget {
  final List<LeaderBoardModel> leaderBoardData;
  const Rank({super.key, required this.leaderBoardData});

  @override
  State<Rank> createState() => _RankState();
}

class _RankState extends State<Rank> {
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  LeaderBoardModel currentUser = LeaderBoardModel();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  String userId = '';
  @override
  initState() {
    super.initState();

    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  TextStyle textStyle(fontSize) => TextStyle(
        fontWeight: FontWeight.w600,
        fontSize: fontSize,
        fontFamily: GoogleFonts.plusJakartaSans().fontFamily,
      );
  @override
  Widget build(BuildContext context) {
    return Container(
        decoration: const BoxDecoration(
          color: Colors.white,
        ),
        padding: const EdgeInsets.only(
            top: 25.0, left: 5.0, right: 5.0, bottom: 30.0),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Container(
                  child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Text(
                        widget.leaderBoardData[1].rank.toString(),
                        textAlign: TextAlign.start,
                        style: TextStyle(
                          fontSize: 20.0,
                          fontWeight: FontWeight.bold,
                          color: Color(0xFFff8725),
                        ),
                      ))),
              Container(
                decoration: const BoxDecoration(
                  shape: BoxShape.circle,
                ),
                child: ClipOval(
                    child: CachedNetworkImage(
                  key: UniqueKey(),
                  imageUrl:
                      widget.leaderBoardData[1].profileImageUrl.toString() +
                          sasToken,
                  width: 55.0,
                  height: 55.0,
                  fit: BoxFit.fill,
                  placeholder: (context, url) => const AvatarPlaceHolder(),
                  errorWidget: (context, url, error) =>
                      const AvatarPlaceHolder(),
                )),
              ),
              Padding(
                  padding: const EdgeInsets.only(top: 10.0),
                  child: Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        SizedBox(
                            width: 100,
                            child: Text(
                              widget.leaderBoardData[1].userName.toString(),
                              style: textStyle(16.0),
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                              textAlign: TextAlign.center,
                            )),
                        Text(
                          '${widget.leaderBoardData[1].score}',
                          style: textStyle(16.0),
                        )
                      ]))
            ]),
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                                Container(
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                      child: CachedNetworkImage(
                          key: UniqueKey(),
                          imageUrl: widget.leaderBoardData[0].profileImageUrl
                                  .toString() +
                              sasToken,
                          width: 75,
                          height: 75,
                          fit: BoxFit.fill,
                          placeholder: (context, url) =>
                              const AvatarPlaceHolder(),
                          errorWidget: (context, url, error) =>
                              const AvatarPlaceHolder()),
                    )),
                Padding(
                    padding: const EdgeInsets.only(top: 10.0),
                    child: Column(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          SizedBox(
                              width: 100,
                              child: Text(
                                widget.leaderBoardData[0].userName.toString(),
                                style: textStyle(16.0),
                                softWrap: false,
                                overflow: TextOverflow.ellipsis,
                                textAlign: TextAlign.center,
                              )),
                          Text(
                            '${widget.leaderBoardData[0].score}',
                            style: textStyle(16.0),
                          )
                        ]))
              ],
            ),
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Container(
                  child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Text(
                        widget.leaderBoardData[2].rank.toString(),
                        textAlign: TextAlign.start,
                        style: TextStyle(
                          fontSize: 20.0,
                          fontWeight: FontWeight.bold,
                          color: Color(0xFFff8725),
                        ),
                      ))),
              Stack(clipBehavior: Clip.none, children: [
                Container(
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                      child: CachedNetworkImage(
                        key: UniqueKey(),
                        imageUrl: widget.leaderBoardData[2].profileImageUrl
                                .toString() +
                            sasToken,
                        width: 55.0,
                        height: 55.0,
                        fit: BoxFit.fill,
                        placeholder: (context, url) =>
                            const AvatarPlaceHolder(),
                        errorWidget: (context, url, error) =>
                            const AvatarPlaceHolder(),
                      ),
                    )),
              ]),
              Padding(
                padding: const EdgeInsets.only(top: 10.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    SizedBox(
                        width: 100,
                        child: Text(
                          widget.leaderBoardData[2].userName.toString(),
                          style: textStyle(16.0),
                          softWrap: false,
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.center,
                        )),
                    Text(
                      '${widget.leaderBoardData[2].score}',
                      style: textStyle(16.0),
                    )
                  ],
                ),
              )
            ]),
          ],
        ));
  }
}
